### ALDEx2 README ###
# ALDEx2 Package (doi: 10.1186/2049-2618-2-15) was implemented following Paragraph 4 on vignette from https://bioconductor.org/packages/release/bioc/html/ALDEx2.html.
# Predicted Pathway counts from Picrust2 were treated as compositional data and trasformed in centered log ratio values (defined as "relative abundances").
# Within and between-groups pathway relative abundances are compared each other by two statistical tests and for every pairwise group comparison.
# INPUT files: "path_abun_unstrat.tsv" is one of the Picrust2 output table, containing predicted quantities (floating numbers) of functional pathways (MetaCyc identifiers)
# It is provided in "\Picrust2\EC_pathway_out" folder. "metadata.tsv" is the original metadata file, defining samples, sample groups and covariates.
# PIPELINE #
# STEP 1: installing and loading ALDEx2 in R environment; pre-processing of pathway count table.
BiocManager::install('ALDEx2')
library(ALDEx2)
path_table<-read.table('path_abun_unstrat.tsv',header=TRUE,comment.char='',fill=TRUE,sep='\t')
metadata<-read.table('metadata.tsv',sep='\t',header=FALSE,skip=2,fill=TRUE,comment.char='')
path_table_rev<-path_table[,-1]
rownames(path_table_rev)<-as.vector(path_table[,1])
sample_names<-gsub('X','',as.vector(colnames(path_table)))
sample_names<-gsub('.','-',as.vector(sample_names),fixed=TRUE)
colnames(path_table_rev)<-sample_names[-1]
path_table_rev<-sapply(path_table_rev, as.integer)
groups<-as.vector(metadata[,2][match(colnames(path_table_rev),metadata[,1])])
#
# STEP 2: comparative matrix generation
comp_matrix<-matrix(groups,length(groups),7)
colnames(comp_matrix)<-c('pouch_paucite','ileum_colon','pouch_colon','pouch_ileum','paucite_ileum','paucite_colon', 'PP_NN')
comp_matrix[,1]<-gsub('Healthy_ileum','NO',comp_matrix[,1])
comp_matrix[,1]<-gsub('Healthy_colon','NO',comp_matrix[,1])
comp_matrix[,1]<-gsub('Paucite',1,comp_matrix[,1])
comp_matrix[,1]<-gsub('Normal_pouch',0,comp_matrix[,1])
comp_matrix[,2]<-gsub('Healthy_ileum',1,comp_matrix[,2])
comp_matrix[,2]<-gsub('Healthy_colon',0,comp_matrix[,2])
comp_matrix[,2]<-gsub('Paucite','NO',comp_matrix[,2])
comp_matrix[,2]<-gsub('Normal_pouch','NO',comp_matrix[,2])
comp_matrix[,3]<-gsub('Healthy_ileum','NO',comp_matrix[,3])
comp_matrix[,3]<-gsub('Healthy_colon',0,comp_matrix[,3])
comp_matrix[,3]<-gsub('Paucite','NO',comp_matrix[,3])
comp_matrix[,3]<-gsub('Normal_pouch',1,comp_matrix[,3])
comp_matrix[,4]<-gsub('Healthy_ileum',0,comp_matrix[,4])
comp_matrix[,4]<-gsub('Healthy_colon','NO',comp_matrix[,4])
comp_matrix[,4]<-gsub('Paucite','NO',comp_matrix[,4])
comp_matrix[,4]<-gsub('Normal_pouch',1,comp_matrix[,4])
comp_matrix[,5]<-gsub('Healthy_ileum',0,comp_matrix[,5])
comp_matrix[,5]<-gsub('Healthy_colon','NO',comp_matrix[,5])
comp_matrix[,5]<-gsub('Paucite',1,comp_matrix[,5])
comp_matrix[,5]<-gsub('Normal_pouch','NO',comp_matrix[,5])
comp_matrix[,6]<-gsub('Healthy_ileum','NO',comp_matrix[,6])
comp_matrix[,6]<-gsub('Healthy_colon',0,comp_matrix[,6])
comp_matrix[,6]<-gsub('Paucite',1,comp_matrix[,6])
comp_matrix[,6]<-gsub('Normal_pouch','NO',comp_matrix[,6])
comp_matrix[,7]<-gsub('Healthy_ileum',0,comp_matrix[,7])
comp_matrix[,7]<-gsub('Healthy_colon',0,comp_matrix[,7])
comp_matrix[,7]<-gsub('Paucite',1,comp_matrix[,7])
comp_matrix[,7]<-gsub('Normal_pouch',1,comp_matrix[,7])
#
# STEP 3: Data selection and ALDEx2 implementation for each comparison, from 1 to 7, as defined by comparative matrix
# "aldex_res" dataframe contains ALDEx2 raw output for each pairwise sample group comparison.
sel<-which(comp_matrix[,1]!='NO') 
aldex_res1 <- aldex(path_table_rev[,sel], as.vector(comp_matrix[sel,1]), mc.samples=128, test="t", effect=TRUE,include.sample.summary=FALSE, denom="all", verbose=FALSE)
sel<-which(comp_matrix[,2]!='NO') 
aldex_res2 <- aldex(path_table_rev[,sel], as.vector(comp_matrix[sel,2]), mc.samples=128, test="t", effect=TRUE,include.sample.summary=FALSE, denom="all", verbose=FALSE)
sel<-which(comp_matrix[,3]!='NO')
aldex_res3 <- aldex(path_table_rev[,sel], as.vector(comp_matrix[sel,3]), mc.samples=128, test="t", effect=TRUE,include.sample.summary=FALSE, denom="all", verbose=FALSE)
sel<-which(comp_matrix[,4]!='NO')
aldex_res4 <- aldex(path_table_rev[,sel], as.vector(comp_matrix[sel,4]), mc.samples=128, test="t", effect=TRUE,include.sample.summary=FALSE, denom="all", verbose=FALSE)
sel<-which(comp_matrix[,5]!='NO')
aldex_res5 <- aldex(path_table_rev[,sel], as.vector(comp_matrix[sel,5]), mc.samples=128, test="t", effect=TRUE,include.sample.summary=FALSE, denom="all", verbose=FALSE)
sel<-which(comp_matrix[,6]!='NO')
aldex_res6 <- aldex(path_table_rev[,sel], as.vector(comp_matrix[sel,6]), mc.samples=128, test="t", effect=TRUE,include.sample.summary=FALSE, denom="all", verbose=FALSE)
sel<-which(comp_matrix[,7]!='NO')
aldex_res7 <- aldex(path_table_rev[,sel], as.vector(comp_matrix[sel,7]), mc.samples=128, test="t", effect=TRUE,include.sample.summary=FALSE, denom="all", verbose=FALSE)
#
## STOP ##
# Session Info
# R version 3.6.1 (2019-07-05)
# Platform: x86_64-w64-mingw32/x64 (64-bit)
# Running under: Windows 10 x64 (build 18363)
# Matrix products: default
# locale:
# [1] LC_COLLATE=Italian_Italy.1252  LC_CTYPE=Italian_Italy.1252    LC_MONETARY=Italian_Italy.1252 LC_NUMERIC=C                  
# [5] LC_TIME=Italian_Italy.1252    
# attached base packages:
# [1] stats     graphics  grDevices utils     datasets  methods   base     
# other attached packages:
# [1] ALDEx2_1.18.0
# loaded via a namespace (and not attached):
# [1] XVector_0.26.0              GenomicRanges_1.38.0        BiocGenerics_0.32.0         splines_3.6.1              
# [5] zlibbioc_1.32.0             MASS_7.3-51.4               IRanges_2.20.2              BiocParallel_1.20.1        
# [9] lattice_0.20-38             GenomeInfoDb_1.22.1         tools_3.6.1                 SummarizedExperiment_1.16.1
# [13] parallel_3.6.1              grid_3.6.1                  Biobase_2.46.0              matrixStats_0.57.0         
# [17] multtest_2.42.0             survival_2.44-1.1           Matrix_1.2-17               GenomeInfoDbData_1.2.2     
# [21] S4Vectors_0.24.4            bitops_1.0-6                RCurl_1.98-1.2              DelayedArray_0.12.3        
# [25] compiler_3.6.1              stats4_3.6.1 



